#[repr(transparent)]pub struct Reload(pub u32);Expand description
The WO digest-reload registers may be written with a saved Hash digest, to allow continuation from where left off. These registers may only be written if the Reload field in CTRL is 1. If SHA1, only the 1st 5 are used.
Tuple Fields
0: u32Implementations